# IronDomo
ZeroMQ Majordomo Pattern with CURVE authentication

Extends ZMQ Majordomo (https://rfc.zeromq.org/spec:7/MDP) pattern with CURVE authentication and encription  
It provides a Broker with two endpoints for client connection, providing both a clear and a trusted communication channels. 
